from setuptools import setup, Extension

acentic_module = Extension(
    name="acentic",
    sources=["acentic/acentic.c"],
)

setup(
    name="acentic",
    version="1.0.1",
    author="Gurumayum Bryan Sharma",
    author_email="mewannacode@example.com",
    description="A module for maths written in PURE C",
    long_description="A fast module for Python made for python in PURE C and uploaded to Pypi because this is a module for Python and its a Module not a library",
    long_description_content_type="text/plain",
    url="https://github.com/mewannacode-egg/acentic",
    ext_modules=[acentic_module],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)